local VERSION = tonumber(("$Revision: 41261 $"):match("%d+"))

if uab.revision < VERSION then
	uab.version = "r" .. VERSION
	uab.revision = VERSION
	uab.date = ("$Date: 2007-06-22 08:09:07 -0400 (Fri, 22 Jun 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

local uabStatus_Dead = uabUnitStatus:NewModule("Dead")

uabStatus_Dead.mixins = {}
uabStatus_Dead.mixins.aura = AceLibrary("SpecialEvents-Aura-2.0")

uabStatus_Dead.defaultDB = {
    disabled = nil,
    checkfeign = false,
    priority = 50,
    color = { r = 1,    g = 0,    b = 0, a = 1, },
    classfilter = {
        druid = true,
        hunter = true,
        mage = true,
        paladin = true,
        priest = true,
        rogue = true,
        shaman = true,
        warlock = true,
        warrior = true,
    },
}

function uabStatus_Dead:OnInitialize()
    self.super.OnInitialize(self)

    self:RegisterEvent("UNIT_HEALTH")
	self:RegisterUnitStatus(self.name)
end

function uabStatus_Dead:UNIT_HEALTH(unit)
    local class = self:GetUnitClass(unit)
    
    if not class or self.db.profile.classfilter[class] then
        if UnitIsDeadOrGhost(unit) then
            if not self.db.profile.checkfeign or not self.mixins.aura:UnitHasBuff(unit, "Feign Death") then
                self.isdead = true
                self:UnitStatusGained(self.name, unit)
            elseif self.isdead then
                self.isdead = nil
                self:UnitStatusLost(self.name, unit)
            end
        elseif self.isdead then
            self.isdead = nil
            self:UnitStatusLost(self.name, unit)
        end
    end
end

function uabStatus_Dead:OnEnable()
end

function uabStatus_Dead:OnDisable()
end

function uabStatus_Dead:IsStatusGained(name, unit, action)
    local class = self:GetUnitClass(unit)
    
    if not class or self.db.profile.classfilter[class] then
    	if name == self.name then
        	if UnitIsDeadOrGhost(unit) then
		        if not self.db.profile.checkfeign or not self.mixins.aura:UnitHasBuff(unit, "Feign Death") then
                    return true
                end
            end
    	end
    end
end

function uabStatus_Dead:CreateUnitStatusOptions()
    local args = self:CreateUnitStatusOption(self.db.profile, "Dead", "Dead", true)

    args.args.feign = {
        type = 'toggle',
        name = "Feign Death",
        desc = "When checked, enable checking for a feign death to avoid false 'dead' indications",
        order = 6,
        get = function()
            return self.db.profile.checkfeign
        end,
        set = function(v)
            self.db.profile.checkfeign = v
        end,
    }
    
    return args
end

